summaryrefslogtreecommitdiffstats
path: root/kdeui/ktabctl.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:46:43 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:46:43 +0000
commitffe8a83e053396df448e9413828527613ca3bd46 (patch)
treea73d4169e02df4a50f9a12cb165fcd0ab5bac7c6 /kdeui/ktabctl.h
parent682bf3bfdcbcbb1fca85e8a36ed03e062e0555d5 (diff)
downloadtdelibs-ffe8a83e053396df448e9413828527613ca3bd46.tar.gz
tdelibs-ffe8a83e053396df448e9413828527613ca3bd46.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1157647 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdeui/ktabctl.h')
-rw-r--r--kdeui/ktabctl.h36
1 files changed, 18 insertions, 18 deletions
diff --git a/kdeui/ktabctl.h b/kdeui/ktabctl.h
index c8cb3cf1b..9c390351f 100644
--- a/kdeui/ktabctl.h
+++ b/kdeui/ktabctl.h
@@ -23,17 +23,17 @@
#ifndef KTABCTL_H
#define KTABCTL_H
-#include <qwidget.h>
-#include <qtabbar.h>
-#include <qmemarray.h>
+#include <tqwidget.h>
+#include <tqtabbar.h>
+#include <tqmemarray.h>
#include <kdelibs_export.h>
/**
* Tabbed dialog with extended features.
* KTabCtl is very similar to QTabDialog, with the following differences:
*
* @li To avoid confusion, the API is almost identical with QTabDialog.
* @li Does not create any buttons, therefore KTabCtl is not limited
* to dialog boxes. You can use it whereever you want.
* @li emits the signal tabSelected(int pagenumber) when the user
@@ -50,23 +50,23 @@ class KDEUI_EXPORT KTabCtl : public QWidget
Q_OBJECT
public:
- KTabCtl(QWidget *parent = 0, const char *name = 0);
+ KTabCtl(TQWidget *parent = 0, const char *name = 0);
~KTabCtl();
void show();
- void setFont(const QFont & font);
- void setTabFont( const QFont &font );
+ void setFont(const TQFont & font);
+ void setTabFont( const TQFont &font );
- void addTab(QWidget *, const QString&);
- bool isTabEnabled(const QString& );
- void setTabEnabled(const QString&, bool);
+ void addTab(TQWidget *, const TQString&);
+ bool isTabEnabled(const TQString& );
+ void setTabEnabled(const TQString&, bool);
void setBorder(bool);
- void setShape( QTabBar::Shape shape );
- virtual QSize sizeHint() const;
+ void setShape( TQTabBar::Shape shape );
+ virtual TQSize sizeHint() const;
protected:
- void paintEvent(QPaintEvent *);
- void resizeEvent(QResizeEvent *);
+ void paintEvent(TQPaintEvent *);
+ void resizeEvent(TQResizeEvent *);
signals:
void tabSelected(int);
@@ -76,10 +76,10 @@ protected slots:
protected:
void setSizes();
- QRect getChildRect() const;
+ TQRect getChildRect() const;
- QTabBar * tabs;
- QMemArray<QWidget *> pages;
+ TQTabBar * tabs;
+ TQMemArray<TQWidget *> pages;
int bh;
bool blBorder;
protected:
@@ -23,17 +23,17 @@
/**
* Tabbed dialog with extended features.
- * KTabCtl is very similar to QTabDialog, with the following differences:
+ * KTabCtl is very similar to TQTabDialog, with the following differences:
*
@@ -23,17 +23,17 @@
*
- * @li To avoid confusion, the API is almost identical with QTabDialog.
+ * @li To avoid confusion, the API is almost identical with TQTabDialog.
* @li Does not create any buttons, therefore KTabCtl is not limited
* to dialog boxes. You can use it whereever you want.